#ifndef APPLICATIONSTATISTICSVIEW_H
#define APPLICATIONSTATISTICSVIEW_H

#include "ApplicationView.h"

#include <QLabel>

class ColumbusStatisticsViewPrivate;

class ColumbusStatisticsView : public ApplicationView
{
    Q_OBJECT

public:
    explicit ColumbusStatisticsView(QWidget *parent = 0);

    QString friendlyName() const;
    void setController(ApplicationController *controller);

    void setupUi();

protected slots:
    void updateUi();

    void onLandscape();
    void onPortrait();

private:
    QLabel* ValueLabel(const QString &text);

    ColumbusStatisticsViewPrivate *d;
};

#endif // APPLICATIONSTATISTICSVIEW_H
